@@ -2,11 +2,9 @@ from typing import Union
 
 
 from MSApi.ObjectMS import ObjectMS, check_init
-from MSApi.mixin.NameMixin import NameMixin
 
 
-class Attribute(ObjectMS,
-                NameMixin):
+class Attribute(ObjectMS):
 
     @check_init
     def get_value(self) -> Union[str]:
